aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/main/java/com/google/devtools/build/lib/actions/ActionExecutionMetadata.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/main/java/com/google/devtools/build/lib/actions/ActionExecutionMetadata.java')
-rw-r--r--src/main/java/com/google/devtools/build/lib/actions/ActionExecutionMetadata.java32
1 files changed, 17 insertions, 15 deletions
diff --git a/src/main/java/com/google/devtools/build/lib/actions/ActionExecutionMetadata.java b/src/main/java/com/google/devtools/build/lib/actions/ActionExecutionMetadata.java
index 7f4b569b13..ec94b6c72a 100644
--- a/src/main/java/com/google/devtools/build/lib/actions/ActionExecutionMetadata.java
+++ b/src/main/java/com/google/devtools/build/lib/actions/ActionExecutionMetadata.java
@@ -59,35 +59,36 @@ public interface ActionExecutionMetadata extends ActionAnalysisMetadata {
* <p>Examples of changes that should affect the key are:
*
* <ul>
- * <li>Changes to the BUILD file that materially affect the rule which gave rise to this Action.
- * <li>Changes to the command-line options, environment, or other global configuration resources
- * which affect the behaviour of this kind of Action (other than changes to the names of the
- * input/output files, which are handled externally).
- * <li>An upgrade to the build tools which changes the program logic of this kind of Action
- * (typically this is achieved by incorporating a UUID into the key, which is changed each
- * time the program logic of this action changes).
+ * <li>Changes to the BUILD file that materially affect the rule which gave rise to this Action.
+ * <li>Changes to the command-line options, environment, or other global configuration resources
+ * which affect the behaviour of this kind of Action (other than changes to the names of the
+ * input/output files, which are handled externally).
+ * <li>An upgrade to the build tools which changes the program logic of this kind of Action
+ * (typically this is achieved by incorporating a UUID into the key, which is changed each
+ * time the program logic of this action changes).
* </ul>
*/
- String getKey();
+ String getKey(ActionKeyContext actionKeyContext);
/**
* Returns a human-readable description of the inputs to {@link #getKey()}.
* Used in the output from '--explain', and in error messages for
* '--check_up_to_date' and '--check_tests_up_to_date'.
* May return null, meaning no extra information is available.
*
* <p>If the return value is non-null, for consistency it should be a multiline message of the
* form:
+ *
* <pre>
* <var>Summary</var>
* <var>Fieldname</var>: <var>value</var>
* <var>Fieldname</var>: <var>value</var>
* ...
* </pre>
+ *
* where each line after the first one is intended two spaces, and where any fields that might
* contain newlines or other funny characters are escaped using {@link
- * com.google.devtools.build.lib.shell.ShellUtils#shellEscape}.
- * For example:
+ * com.google.devtools.build.lib.shell.ShellUtils#shellEscape}. For example:
+ *
* <pre>
* Compiling foo.cc
* Command: /usr/bin/gcc
@@ -97,7 +98,8 @@ public interface ActionExecutionMetadata extends ActionAnalysisMetadata {
* Argument: foo.o
* </pre>
*/
- @Nullable String describeKey();
+ @Nullable
+ String describeKey();
/**
* Get the {@link RunfilesSupplier} providing runfiles needed by this action.
@@ -59,35 +59,36 @@ public interface ActionExecutionMetadata extends ActionAnalysisMetadata {
/**
- * Returns a human-readable description of the inputs to {@link #getKey()}.
- * Used in the output from '--explain', and in error messages for
- * '--check_up_to_date' and '--check_tests_up_to_date'.
- * May return null, meaning no extra information is available.
+ * Returns a human-readable description of the inputs to {@link #getKey(ActionKeyContext)}. Used
+ * in the output from '--explain', and in error messages for '--check_up_to_date' and
+ * '--check_tests_up_to_date'. May return null, meaning no extra information is available.
*
* <p>If the return value is non-null, for consistency it should be a multiline message of the